gatein SVN: r7547 - epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf.
by do-not-reply@jboss.org
Author: chris.laprun(a)jboss.com
Date: 2011-09-28 06:17:50 -0400 (Wed, 28 Sep 2011)
New Revision: 7547
Modified:
epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties
Log:
- Better comment
Modified: epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties 2011-09-28 10:11:21 UTC (rev 7546)
+++ epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties 2011-09-28 10:17:50 UTC (rev 7547)
@@ -51,7 +51,7 @@
gatein.email.smtp.socketFactory.port=465
gatein.email.smtp.socketFactory.class=javax.net.ssl.SSLSocketFactory
-# Global portlet.xml
+# Portlet container configuration
gatein.portlet.validation=true
gatein.portlet.config=${gatein.conf.dir}/portlet.xml
13 years, 3 months
gatein SVN: r7546 - in epp/portal/branches/EPP_5_2_Branch: component/pc/src/main/java/org/exoplatform/portal/pc and 2 other directories.
by do-not-reply@jboss.org
Author: chris.laprun(a)jboss.com
Date: 2011-09-28 06:11:21 -0400 (Wed, 28 Sep 2011)
New Revision: 7546
Modified:
epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java
epp/portal/branches/EPP_5_2_Branch/pom.xml
epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java
epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml
Log:
- Only use one FederatingPortletInvoker instance instead of having one per portal container so that WSRP can work in clustered environments.
- Updated to use WSRP 2.1.0-Beta06 and changes to PC 2.3.0-Beta06.
Modified: epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java 2011-09-28 09:58:15 UTC (rev 7545)
+++ epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java 2011-09-28 10:11:21 UTC (rev 7546)
@@ -27,6 +27,7 @@
import org.gatein.common.logging.LoggerFactory;
import org.gatein.pc.api.PortletInvoker;
import org.gatein.pc.bridge.BridgeInterceptor;
+import org.gatein.pc.federation.FederatedPortletInvoker;
import org.gatein.pc.federation.FederatingPortletInvoker;
import org.gatein.pc.federation.impl.FederatingPortletInvokerService;
import org.gatein.pc.portlet.PortletInvokerInterceptor;
@@ -91,7 +92,7 @@
portletApplicationRegistry = new ExoPortletApplicationDeployer();
portletApplicationRegistry.setContainerPortletInvoker(containerPortletInvoker);
- //
+ // activate schema validation for portlet.xml if needed
String validation = PropertyManager.getProperty("gatein.portlet.validation");
boolean validated = validation == null || "true".equals(validation.trim().toLowerCase());
log.debug("portlet xml validation is " + (validated ? "enabled" : " disabled"));
@@ -100,9 +101,15 @@
//Container Stack
ContainerPortletDispatcher portletContainerDispatcher = new ContainerPortletDispatcher();
- // Federating portlet invoker
- FederatingPortletInvoker federatingPortletInvoker = new FederatingPortletInvokerService();
-
+ // Check if we already have a federating portlet invoker
+ final ExoContainer topContainer = ExoContainerContext.getTopContainer();
+ FederatingPortletInvoker federatingPortletInvoker = (FederatingPortletInvoker)topContainer.getComponentInstanceOfType(FederatingPortletInvoker.class);
+ if (federatingPortletInvoker == null)
+ {
+ federatingPortletInvoker = new FederatingPortletInvokerService();
+ topContainer.registerComponentInstance(FederatingPortletInvoker.class, federatingPortletInvoker);
+ }
+
EventPayloadInterceptor eventPayloadInterceptor = new EventPayloadInterceptor();
eventPayloadInterceptor.setNext(portletContainerDispatcher);
RequestAttributeConversationInterceptor requestAttributeConversationInterceptor =
@@ -141,17 +148,21 @@
producerStateManagementPolicy.setPersistLocally(false);
// The producer state converter
- StateConverter producerStateConverter = new ExoStateConverter();//StateConverterV0();
+ StateConverter producerStateConverter = new ExoStateConverter();
// The producer portlet invoker
ProducerPortletInvoker producerPortletInvoker = new ProducerPortletInvoker();
producerPortletInvoker.setNext(containerPortletInvoker);
- federatingPortletInvoker.registerInvoker(PortletInvoker.LOCAL_PORTLET_INVOKER_ID, producerPortletInvoker);
-
producerPortletInvoker.setPersistenceManager(producerPersistenceManager);
producerPortletInvoker.setStateManagementPolicy(producerStateManagementPolicy);
producerPortletInvoker.setStateConverter(producerStateConverter);
+ // register the producer portlet invoker if it hasn't been already
+ if(!federatingPortletInvoker.isResolved(PortletInvoker.LOCAL_PORTLET_INVOKER_ID))
+ {
+ federatingPortletInvoker.registerInvoker(PortletInvoker.LOCAL_PORTLET_INVOKER_ID, producerPortletInvoker);
+ }
+
// The consumer portlet invoker
PortletCustomizationInterceptor portletCustomizationInterceptor = new PortletCustomizationInterceptor();
portletCustomizationInterceptor.setNext(federatingPortletInvoker);
Modified: epp/portal/branches/EPP_5_2_Branch/pom.xml
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/pom.xml 2011-09-28 09:58:15 UTC (rev 7545)
+++ epp/portal/branches/EPP_5_2_Branch/pom.xml 2011-09-28 10:11:21 UTC (rev 7546)
@@ -53,7 +53,7 @@
<org.gatein.wci.version>2.1.0-Beta06</org.gatein.wci.version>
<org.gatein.pc.version>2.3.0-Beta06</org.gatein.pc.version>
<org.picketlink.idm>1.3.0.Alpha04</org.picketlink.idm>
- <org.gatein.wsrp.version>2.1.0-Beta05</org.gatein.wsrp.version>
+ <org.gatein.wsrp.version>2.1.0-Beta06</org.gatein.wsrp.version>
<org.gatein.mop.version>1.1.0-Beta05</org.gatein.mop.version>
<org.gatein.mgmt.version>1.0.0-Beta03</org.gatein.mgmt.version>
<org.slf4j.version>1.5.8</org.slf4j.version>
Modified: epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml 2011-09-28 09:58:15 UTC (rev 7545)
+++ epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml 2011-09-28 10:11:21 UTC (rev 7546)
@@ -25,7 +25,7 @@
<deployments xmlns="http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0 http://www.jboss.org/portal/xsd/gatein_wsrp_consumer_1_0.xsd">
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0 http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0.xsd">
<deployment>
<wsrp-producer id="selfv1" expiration-cache="500" ws-timeout="50000">
<endpoint-wsdl-url>http://localhost:8080/wsrp-producer/v1/MarkupService?wsdl</endpoint-wsdl-url>
@@ -91,4 +91,4 @@
<registration-data/>
</wsrp-producer>
</deployment>-->
-</deployments>
\ No newline at end of file
+</deployments>
13 years, 3 months
gatein SVN: r7545 - in epp/portal/branches/EPP_5_2_Branch: component/common/src/main/java/conf and 1 other directories.
by do-not-reply@jboss.org
Author: chris.laprun(a)jboss.com
Date: 2011-09-28 05:58:15 -0400 (Wed, 28 Sep 2011)
New Revision: 7545
Modified:
epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties
epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java
epp/portal/branches/EPP_5_2_Branch/pom.xml
Log:
- Upgraded to PC 2.3.0-Beta06.
Modified: epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties 2011-09-28 09:36:06 UTC (rev 7544)
+++ epp/portal/branches/EPP_5_2_Branch/component/common/src/main/java/conf/configuration-jboss.properties 2011-09-28 09:58:15 UTC (rev 7545)
@@ -52,6 +52,7 @@
gatein.email.smtp.socketFactory.class=javax.net.ssl.SSLSocketFactory
# Global portlet.xml
+gatein.portlet.validation=true
gatein.portlet.config=${gatein.conf.dir}/portlet.xml
# Portal configuration
Modified: epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java 2011-09-28 09:36:06 UTC (rev 7544)
+++ epp/portal/branches/EPP_5_2_Branch/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java 2011-09-28 09:58:15 UTC (rev 7545)
@@ -19,9 +19,12 @@
package org.exoplatform.portal.pc;
+import org.exoplatform.commons.utils.PropertyManager;
import org.exoplatform.container.ExoContainer;
import org.exoplatform.container.ExoContainerContext;
import org.exoplatform.services.resources.ResourceBundleService;
+import org.gatein.common.logging.Logger;
+import org.gatein.common.logging.LoggerFactory;
import org.gatein.pc.api.PortletInvoker;
import org.gatein.pc.bridge.BridgeInterceptor;
import org.gatein.pc.federation.FederatingPortletInvoker;
@@ -54,6 +57,7 @@
public class ExoKernelIntegration implements Startable
{
+ /** . */
protected PortletApplicationDeployer portletApplicationRegistry;
/** Exo Context */
@@ -62,6 +66,9 @@
/** DO NOT REMOVE ME, OTHERWISE YOU'LL BREAK THINGS. */
private final ResourceBundleService resourceBundleService;
+ /** . */
+ private Logger log = LoggerFactory.getLogger(ExoKernelIntegration.class);
+
/**
* We enforce the dependency with the ResourceBundleService since it must be stared before the
* <code>portletApplicationRegistry</code>
@@ -84,6 +91,12 @@
portletApplicationRegistry = new ExoPortletApplicationDeployer();
portletApplicationRegistry.setContainerPortletInvoker(containerPortletInvoker);
+ //
+ String validation = PropertyManager.getProperty("gatein.portlet.validation");
+ boolean validated = validation == null || "true".equals(validation.trim().toLowerCase());
+ log.debug("portlet xml validation is " + (validated ? "enabled" : " disabled"));
+ portletApplicationRegistry.setSchemaValidated(validated);
+
//Container Stack
ContainerPortletDispatcher portletContainerDispatcher = new ContainerPortletDispatcher();
Modified: epp/portal/branches/EPP_5_2_Branch/pom.xml
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/pom.xml 2011-09-28 09:36:06 UTC (rev 7544)
+++ epp/portal/branches/EPP_5_2_Branch/pom.xml 2011-09-28 09:58:15 UTC (rev 7545)
@@ -51,7 +51,7 @@
<org.gatein.common.version>2.0.4-Beta03</org.gatein.common.version>
<org.gatein.dep.version>1.1.0-Beta06</org.gatein.dep.version>
<org.gatein.wci.version>2.1.0-Beta06</org.gatein.wci.version>
- <org.gatein.pc.version>2.3.0-Beta05</org.gatein.pc.version>
+ <org.gatein.pc.version>2.3.0-Beta06</org.gatein.pc.version>
<org.picketlink.idm>1.3.0.Alpha04</org.picketlink.idm>
<org.gatein.wsrp.version>2.1.0-Beta05</org.gatein.wsrp.version>
<org.gatein.mop.version>1.1.0-Beta05</org.gatein.mop.version>
@@ -63,7 +63,7 @@
<javax.servlet.version>2.5</javax.servlet.version>
<version.chromattic>1.1.0-beta6</version.chromattic>
<version.reflect>1.1.0-beta12</version.reflect>
- <org.staxnav.version>0.9.4</org.staxnav.version>
+ <org.staxnav.version>0.9.6</org.staxnav.version>
<jcip.version>1.0</jcip.version>
<commons-dbcp.version>1.2.2</commons-dbcp.version>
13 years, 3 months
gatein SVN: r7544 - epp/portal/branches/EPP_5_2_Branch/portlet/exoadmin/src/main/webapp/WEB-INF.
by do-not-reply@jboss.org
Author: chris.laprun(a)jboss.com
Date: 2011-09-28 05:36:06 -0400 (Wed, 28 Sep 2011)
New Revision: 7544
Modified:
epp/portal/branches/EPP_5_2_Branch/portlet/exoadmin/src/main/webapp/WEB-INF/portlet.xml
Log:
- Fixed improper order of elements as this will cause problems with the new metadata parser.
Modified: epp/portal/branches/EPP_5_2_Branch/portlet/exoadmin/src/main/webapp/WEB-INF/portlet.xml
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/portlet/exoadmin/src/main/webapp/WEB-INF/portlet.xml 2011-09-28 04:09:11 UTC (rev 7543)
+++ epp/portal/branches/EPP_5_2_Branch/portlet/exoadmin/src/main/webapp/WEB-INF/portlet.xml 2011-09-28 09:36:06 UTC (rev 7544)
@@ -23,11 +23,6 @@
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xsi:schemaLocation="http://java.sun.com/xml/ns/portlet/portlet-app_2_0.xsd http://java.sun.com/xml/ns/portlet/portlet-app_2_0.xsd">
- <public-render-parameter>
- <identifier>navigation_uri</identifier>
- <qname xmlns:prp='http://www.gatein.org/xml/ns/prp_1_0'>prp:navigation_uri</qname>
- </public-render-parameter>
-
<portlet>
<description xml:lang="EN">Organization Portlet</description>
<portlet-name>OrganizationPortlet</portlet-name>
@@ -437,4 +432,9 @@
<event-definition>
<name>NavigationChange</name>
</event-definition>
+
+ <public-render-parameter>
+ <identifier>navigation_uri</identifier>
+ <qname xmlns:prp='http://www.gatein.org/xml/ns/prp_1_0'>prp:navigation_uri</qname>
+ </public-render-parameter>
</portlet-app>
13 years, 3 months
gatein SVN: r7543 - epp/portal/branches/EPP_5_2_Branch/component/web/controller.
by do-not-reply@jboss.org
Author: theute
Date: 2011-09-28 00:09:11 -0400 (Wed, 28 Sep 2011)
New Revision: 7543
Modified:
epp/portal/branches/EPP_5_2_Branch/component/web/controller/pom.xml
Log:
Upgrading japex to work with Maven 3
Modified: epp/portal/branches/EPP_5_2_Branch/component/web/controller/pom.xml
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/component/web/controller/pom.xml 2011-09-28 01:26:38 UTC (rev 7542)
+++ epp/portal/branches/EPP_5_2_Branch/component/web/controller/pom.xml 2011-09-28 04:09:11 UTC (rev 7543)
@@ -93,12 +93,13 @@
</exclusions>
</dependency>
</dependencies>
+
<build>
<plugins>
<plugin>
<groupId>com.sun.japex</groupId>
<artifactId>japex-maven-plugin</artifactId>
- <version>1.2.3</version>
+ <version>1.2.4</version>
<executions>
<execution>
<id>japex</id>
@@ -143,7 +144,6 @@
</plugin>
</plugins>
</build>
-
<profiles>
<profile>
13 years, 3 months
gatein SVN: r7542 - in epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14: en-US and 3 other directories.
by do-not-reply@jboss.org
Author: smumford
Date: 2011-09-27 21:26:38 -0400 (Tue, 27 Sep 2011)
New Revision: 7542
Added:
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.ent
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.xml
Removed:
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.ent
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.xml
Modified:
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/extras/Authentication_Identity_SSO/default128.xml
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/images/Advanced/Foundations/PortalContainers.png
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/modules/Advanced/eXoJCR/jcr/searching/jcr-query-usecases.xml
epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/publican.cfg
Log:
Changed Book name to differentiate branch
Deleted: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.ent
===================================================================
--- epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.ent 2011-09-27 20:51:19 UTC (rev 7541)
+++ epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.ent 2011-09-28 01:26:38 UTC (rev 7542)
@@ -1,19 +0,0 @@
-<!-- Product Specifics: -->
-<!ENTITY PRODUCT "JBoss Enterprise Portal Platform">
-
-<!-- Book specifics: -->
-<!ENTITY BOOKID "Reference Guide">
-
-<!-- Bugzilla Specifics -->
-<!ENTITY BZPRODUCT "JBoss Enterprise Portal Platform 5">
-<!ENTITY BZCOMPONENT "docs-Reference_Guide">
-<!ENTITY BZURL "<ulink url='https://bugzilla.redhat.com/enter_bug.cgi?product=JBoss%20Enterpri...'>http://bugzilla.redhat.com/</ulink>">
-
-<!-- Corporate Specifics: -->
-<!ENTITY YEAR "2011">
-<!ENTITY HOLDER "Red Hat, Inc">
-
-<!-- Version Specifcs: -->
-<!ENTITY VX "5">
-<!ENTITY VY "5.2">
-<!ENTITY VZ "5.2.0">
\ No newline at end of file
Deleted: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.xml
===================================================================
--- epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.xml 2011-09-27 20:51:19 UTC (rev 7541)
+++ epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.xml 2011-09-28 01:26:38 UTC (rev 7542)
@@ -1,18 +0,0 @@
-<?xml version='1.0' encoding='utf-8' ?>
-<!DOCTYPE book PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN" "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd" [
-<!ENTITY % BOOK_ENTITIES SYSTEM "Reference_Guide.ent">
-%BOOK_ENTITIES;
-]>
-<book>
- <xi:include href="Book_Info.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <xi:include href="Preface.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <xi:include href="modules/Introduction.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <xi:include href="modules/PortalDevelopment.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <xi:include href="modules/PortletDevelopment.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <!-- <xi:include href="modules/GadgetDevelopment.xml" xmlns:xi="http://www.w3.org/2001/XInclude" /> -->
- <xi:include href="modules/AuthenticationAndIdentity.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <xi:include href="modules/WSRP.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <xi:include href="modules/Advanced.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
- <xi:include href="Revision_History.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
-</book>
-
Copied: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.ent (from rev 7507, epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.ent)
===================================================================
--- epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.ent (rev 0)
+++ epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.ent 2011-09-28 01:26:38 UTC (rev 7542)
@@ -0,0 +1,19 @@
+<!-- Product Specifics: -->
+<!ENTITY PRODUCT "JBoss Enterprise Portal Platform">
+
+<!-- Book specifics: -->
+<!ENTITY BOOKID "Reference Guide">
+
+<!-- Bugzilla Specifics -->
+<!ENTITY BZPRODUCT "JBoss Enterprise Portal Platform 5">
+<!ENTITY BZCOMPONENT "docs-Reference_Guide">
+<!ENTITY BZURL "<ulink url='https://bugzilla.redhat.com/enter_bug.cgi?product=JBoss%20Enterpri...'>http://bugzilla.redhat.com/</ulink>">
+
+<!-- Corporate Specifics: -->
+<!ENTITY YEAR "2011">
+<!ENTITY HOLDER "Red Hat, Inc">
+
+<!-- Version Specifcs: -->
+<!ENTITY VX "5">
+<!ENTITY VY "5.2">
+<!ENTITY VZ "5.2.0">
\ No newline at end of file
Copied: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.xml (from rev 7508, epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide.xml)
===================================================================
--- epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.xml (rev 0)
+++ epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/Reference_Guide_eXo_JCR_1.14.xml 2011-09-28 01:26:38 UTC (rev 7542)
@@ -0,0 +1,18 @@
+<?xml version='1.0' encoding='utf-8' ?>
+<!DOCTYPE book PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN" "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd" [
+<!ENTITY % BOOK_ENTITIES SYSTEM "Reference_Guide.ent">
+%BOOK_ENTITIES;
+]>
+<book>
+ <xi:include href="Book_Info.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <xi:include href="Preface.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <xi:include href="modules/Introduction.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <xi:include href="modules/PortalDevelopment.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <xi:include href="modules/PortletDevelopment.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <!-- <xi:include href="modules/GadgetDevelopment.xml" xmlns:xi="http://www.w3.org/2001/XInclude" /> -->
+ <xi:include href="modules/AuthenticationAndIdentity.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <xi:include href="modules/WSRP.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <xi:include href="modules/Advanced.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+ <xi:include href="Revision_History.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
+</book>
+
Modified: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/extras/Authentication_Identity_SSO/default128.xml
===================================================================
--- epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/extras/Authentication_Identity_SSO/default128.xml 2011-09-27 20:51:19 UTC (rev 7541)
+++ epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/extras/Authentication_Identity_SSO/default128.xml 2011-09-28 01:26:38 UTC (rev 7542)
@@ -1,20 +1,13 @@
- <filter>
- <filter-name>LoginRedirectFilter</filter-name>
- <filter-class>org.gatein.sso.agent.filter.LoginRedirectFilter</filter-class>
- <init-param>
- <!-- This should point to your SSO authentication server -->
- <param-name>LOGIN_URL</param-name>
- <param-value>/portal/private/classic</param-value>
- </filter>
- <filter>
- <filter-name>SPNEGOFilter</filter-name>
- <filter-class>org.gatein.sso.agent.filter.SPNEGOFilter</filter-class>
- </filter>
- <filter-mapping>
- <filter-name>LoginRedirectFilter</filter-name>
- <url-pattern>/*</url-pattern>
- </filter-mapping>
- <filter-mapping>
- <filter-name>SPNEGOFilter</filter-name>
- <url-pattern>/*</url-pattern>
- </filter-mapping>
\ No newline at end of file
+<filter>
+ <filter-name>LoginRedirectFilter</filter-name>
+ <filter-class>org.gatein.sso.agent.filter.LoginRedirectFilter</filter-class>
+ <init-param>
+ <!-- This should point to your SSO authentication server -->
+ <param-name>LOGIN_URL</param-name>
+ <param-value>/portal/private/classic</param-value>
+ </init-param>
+</filter>
+<filter-mapping>
+ <filter-name>LoginRedirectFilter</filter-name>
+ <url-pattern>/*</url-pattern>
+</filter-mapping>
\ No newline at end of file
Modified: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/images/Advanced/Foundations/PortalContainers.png
===================================================================
(Binary files differ)
Modified: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/modules/Advanced/eXoJCR/jcr/searching/jcr-query-usecases.xml
===================================================================
--- epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/modules/Advanced/eXoJCR/jcr/searching/jcr-query-usecases.xml 2011-09-27 20:51:19 UTC (rev 7541)
+++ epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/en-US/modules/Advanced/eXoJCR/jcr/searching/jcr-query-usecases.xml 2011-09-28 01:26:38 UTC (rev 7542)
@@ -329,7 +329,7 @@
</listitem>
<listitem>
<para>
- <xref linkend="sect-Reference_Guide-Searching_By_Synonim" />
+ <xref linkend="sect-Reference_Guide-Searching_By_Synonym" />
</para>
</listitem>
Modified: epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/publican.cfg
===================================================================
--- epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/publican.cfg 2011-09-27 20:51:19 UTC (rev 7541)
+++ epp/docs/branches/5.2/Reference_Guide-eXoJCR-1.14/publican.cfg 2011-09-28 01:26:38 UTC (rev 7542)
@@ -4,9 +4,8 @@
cvs_root: ":ext:cvs.devel.redhat.com:/cvs/dist"
cvs_branch: "DOCS-RHEL-6"
show_remarks: 1
-cvs_pkg: "JBoss_Enterprise_Portal_Platform-Reference_Guide-5.2-web-__LANG__"
+cvs_pkg: "JBoss_Enterprise_Portal_Platform-Reference_Guide_eXo_JCR_1.14-5.2-web-__LANG__"
xml_lang: "en-US"
-mainfile: Reference_Guide
brand: JBoss
debug: 1
type: Book
13 years, 3 months
gatein SVN: r7541 - portal/trunk/component/common/src/main/java/conf.
by do-not-reply@jboss.org
Author: julien_viet
Date: 2011-09-27 16:51:19 -0400 (Tue, 27 Sep 2011)
New Revision: 7541
Modified:
portal/trunk/component/common/src/main/java/conf/configuration-jboss.properties
portal/trunk/component/common/src/main/java/conf/configuration-jetty.properties
portal/trunk/component/common/src/main/java/conf/configuration-tomcat.properties
Log:
update the comment that describe the portlet container integration configuration
Modified: portal/trunk/component/common/src/main/java/conf/configuration-jboss.properties
===================================================================
--- portal/trunk/component/common/src/main/java/conf/configuration-jboss.properties 2011-09-27 19:21:49 UTC (rev 7540)
+++ portal/trunk/component/common/src/main/java/conf/configuration-jboss.properties 2011-09-27 20:51:19 UTC (rev 7541)
@@ -59,7 +59,7 @@
gatein.email.smtp.socketFactory.port=465
gatein.email.smtp.socketFactory.class=javax.net.ssl.SSLSocketFactory
-# Global portlet.xml
+# Portlet container configuration
gatein.portlet.validation=true
gatein.portlet.config=${gatein.conf.dir}/portlet.xml
Modified: portal/trunk/component/common/src/main/java/conf/configuration-jetty.properties
===================================================================
--- portal/trunk/component/common/src/main/java/conf/configuration-jetty.properties 2011-09-27 19:21:49 UTC (rev 7540)
+++ portal/trunk/component/common/src/main/java/conf/configuration-jetty.properties 2011-09-27 20:51:19 UTC (rev 7541)
@@ -62,7 +62,7 @@
gatein.email.smtp.socketFactory.port=465
gatein.email.smtp.socketFactory.class=javax.net.ssl.SSLSocketFactory
-# Global portlet.xml
+# Portlet container configuration
gatein.portlet.validation=true
gatein.portlet.config=${gatein.conf.dir}/portlet.xml
Modified: portal/trunk/component/common/src/main/java/conf/configuration-tomcat.properties
===================================================================
--- portal/trunk/component/common/src/main/java/conf/configuration-tomcat.properties 2011-09-27 19:21:49 UTC (rev 7540)
+++ portal/trunk/component/common/src/main/java/conf/configuration-tomcat.properties 2011-09-27 20:51:19 UTC (rev 7541)
@@ -62,7 +62,7 @@
gatein.email.smtp.socketFactory.port=465
gatein.email.smtp.socketFactory.class=javax.net.ssl.SSLSocketFactory
-# Global portlet.xml
+# Portlet container configuration
gatein.portlet.validation=true
gatein.portlet.config=${gatein.conf.dir}/portlet.xml
13 years, 3 months
gatein SVN: r7540 - epp/portal/branches/EPP_5_2_Branch/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIPopup/UIPopupCategory.
by do-not-reply@jboss.org
Author: mwringe
Date: 2011-09-27 15:21:49 -0400 (Tue, 27 Sep 2011)
New Revision: 7540
Modified:
epp/portal/branches/EPP_5_2_Branch/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIPopup/UIPopupCategory/Stylesheet.css
Log:
JBEPP-1181: add in css for the UIPopupCategory CategoryItem. Matches what is currently available in GateIn trunk.
Modified: epp/portal/branches/EPP_5_2_Branch/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIPopup/UIPopupCategory/Stylesheet.css
===================================================================
--- epp/portal/branches/EPP_5_2_Branch/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIPopup/UIPopupCategory/Stylesheet.css 2011-09-27 17:34:56 UTC (rev 7539)
+++ epp/portal/branches/EPP_5_2_Branch/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIPopup/UIPopupCategory/Stylesheet.css 2011-09-27 19:21:49 UTC (rev 7540)
@@ -49,6 +49,12 @@
border-bottom: 1px #cdcdcd solid;
cursor: pointer;
display: block;
+ padding-left: 18px; /* orientation=lt */
+ padding-right: 18px; /* orientation=rt */
+ height: 22px;
+ line-height: 22px;
+ background: #efefef url('/eXoResources/skin/DefaultSkin/skinIcons/16x16/icons/GrayNextArrow.gif') no-repeat left center; /* orientation=lt */
+ background: #efefef url('/eXoResources/skin/DefaultSkin/skinIcons/16x16/icons/GrayNextArrow-rt.gif') no-repeat right center; /* orientation=rt */
}
.UIPopupCategory .CategoryItem:hover {
13 years, 3 months
gatein SVN: r7539 - in portal/trunk: component/pc/src/main/java/org/exoplatform/portal/pc and 3 other directories.
by do-not-reply@jboss.org
Author: chris.laprun(a)jboss.com
Date: 2011-09-27 13:34:56 -0400 (Tue, 27 Sep 2011)
New Revision: 7539
Modified:
portal/trunk/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java
portal/trunk/pom.xml
portal/trunk/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java
portal/trunk/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml
portal/trunk/wsrp-integration/extension-config/src/main/resources/conf/configuration.xml
Log:
- Only use one FederatingPortletInvoker instance instead of having one per portal container so that WSRP can work in clustered environments.
- Updated to use WSRP 2.1.0-Beta06 and changes to PC 2.3.0-Beta06.
Modified: portal/trunk/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java
===================================================================
--- portal/trunk/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java 2011-09-27 17:02:31 UTC (rev 7538)
+++ portal/trunk/component/pc/src/main/java/org/exoplatform/portal/pc/ExoKernelIntegration.java 2011-09-27 17:34:56 UTC (rev 7539)
@@ -27,6 +27,7 @@
import org.gatein.common.logging.LoggerFactory;
import org.gatein.pc.api.PortletInvoker;
import org.gatein.pc.bridge.BridgeInterceptor;
+import org.gatein.pc.federation.FederatedPortletInvoker;
import org.gatein.pc.federation.FederatingPortletInvoker;
import org.gatein.pc.federation.impl.FederatingPortletInvokerService;
import org.gatein.pc.portlet.PortletInvokerInterceptor;
@@ -91,7 +92,7 @@
portletApplicationRegistry = new ExoPortletApplicationDeployer();
portletApplicationRegistry.setContainerPortletInvoker(containerPortletInvoker);
- //
+ // activate schema validation for portlet.xml if needed
String validation = PropertyManager.getProperty("gatein.portlet.validation");
boolean validated = validation == null || "true".equals(validation.trim().toLowerCase());
log.debug("portlet xml validation is " + (validated ? "enabled" : " disabled"));
@@ -100,9 +101,15 @@
//Container Stack
ContainerPortletDispatcher portletContainerDispatcher = new ContainerPortletDispatcher();
- // Federating portlet invoker
- FederatingPortletInvoker federatingPortletInvoker = new FederatingPortletInvokerService();
-
+ // Check if we already have a federating portlet invoker
+ final ExoContainer topContainer = ExoContainerContext.getTopContainer();
+ FederatingPortletInvoker federatingPortletInvoker = (FederatingPortletInvoker)topContainer.getComponentInstanceOfType(FederatingPortletInvoker.class);
+ if (federatingPortletInvoker == null)
+ {
+ federatingPortletInvoker = new FederatingPortletInvokerService();
+ topContainer.registerComponentInstance(FederatingPortletInvoker.class, federatingPortletInvoker);
+ }
+
EventPayloadInterceptor eventPayloadInterceptor = new EventPayloadInterceptor();
eventPayloadInterceptor.setNext(portletContainerDispatcher);
RequestAttributeConversationInterceptor requestAttributeConversationInterceptor =
@@ -141,17 +148,21 @@
producerStateManagementPolicy.setPersistLocally(false);
// The producer state converter
- StateConverter producerStateConverter = new ExoStateConverter();//StateConverterV0();
+ StateConverter producerStateConverter = new ExoStateConverter();
// The producer portlet invoker
ProducerPortletInvoker producerPortletInvoker = new ProducerPortletInvoker();
producerPortletInvoker.setNext(containerPortletInvoker);
- federatingPortletInvoker.registerInvoker(PortletInvoker.LOCAL_PORTLET_INVOKER_ID, producerPortletInvoker);
-
producerPortletInvoker.setPersistenceManager(producerPersistenceManager);
producerPortletInvoker.setStateManagementPolicy(producerStateManagementPolicy);
producerPortletInvoker.setStateConverter(producerStateConverter);
+ // register the producer portlet invoker if it hasn't been already
+ if(!federatingPortletInvoker.isResolved(PortletInvoker.LOCAL_PORTLET_INVOKER_ID))
+ {
+ federatingPortletInvoker.registerInvoker(PortletInvoker.LOCAL_PORTLET_INVOKER_ID, producerPortletInvoker);
+ }
+
// The consumer portlet invoker
PortletCustomizationInterceptor portletCustomizationInterceptor = new PortletCustomizationInterceptor();
portletCustomizationInterceptor.setNext(federatingPortletInvoker);
Modified: portal/trunk/pom.xml
===================================================================
--- portal/trunk/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
+++ portal/trunk/pom.xml 2011-09-27 17:34:56 UTC (rev 7539)
@@ -47,7 +47,7 @@
<org.gatein.wci.version>2.1.0-Beta06</org.gatein.wci.version>
<org.gatein.pc.version>2.3.0-Beta06</org.gatein.pc.version>
<org.picketlink.idm>1.3.0.Alpha04</org.picketlink.idm>
- <org.gatein.wsrp.version>2.1.0-Beta05</org.gatein.wsrp.version>
+ <org.gatein.wsrp.version>2.1.0-Beta06</org.gatein.wsrp.version>
<org.gatein.mop.version>1.1.0-Beta06</org.gatein.mop.version>
<org.gatein.mgmt.version>1.0.0-Beta03</org.gatein.mgmt.version>
<org.slf4j.version>1.5.8</org.slf4j.version>
Modified: portal/trunk/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java
===================================================================
--- portal/trunk/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml 2011-09-27 17:02:31 UTC (rev 7538)
+++ portal/trunk/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml 2011-09-27 17:34:56 UTC (rev 7539)
@@ -25,7 +25,7 @@
<deployments xmlns="http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0 http://www.jboss.org/portal/xsd/gatein_wsrp_consumer_1_0.xsd">
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0 http://www.gatein.org/xml/ns/gatein_wsrp_consumer_1_0.xsd">
<deployment>
<wsrp-producer id="selfv1" expiration-cache="500" ws-timeout="50000">
<endpoint-wsdl-url>http://localhost:8080/wsrp-producer/v1/MarkupService?wsdl</endpoint-wsdl-url>
Modified: portal/trunk/wsrp-integration/extension-config/src/main/resources/conf/configuration.xml
===================================================================
--- portal/trunk/wsrp-integration/extension-config/src/main/resources/conf/configuration.xml 2011-09-27 17:02:31 UTC (rev 7538)
+++ portal/trunk/wsrp-integration/extension-config/src/main/resources/conf/configuration.xml 2011-09-27 17:34:56 UTC (rev 7539)
@@ -56,4 +56,33 @@
</init-params>
</component-plugin>
</external-component-plugins>
+
+ <!-- Cache configuration in clustered mode for ConsumerRegistry -->
+ <!--<external-component-plugins>
+ <target-component>org.exoplatform.services.cache.CacheService</target-component>
+ <component-plugin profiles="cluster">
+ <name>addExoCacheConfig</name>
+ <set-method>addExoCacheConfig</set-method>
+ <type>org.exoplatform.services.cache.ExoCacheConfigPlugin</type>
+ <description>add Exo Cache Config</description>
+ <init-params>
+ <object-param>
+ <name>cache.config.DistributedConsumerCache</name>
+ <description>The JBoss Cache configuration for the ConsumerRegistry distributed consumer cache
+ </description>
+ <object type="org.exoplatform.services.cache.ExoCacheConfig">
+ <field name="name">
+ <string>DistributedConsumerCache</string>
+ </field>
+ <field name="liveTime">
+ <long>600</long>
+ </field>
+ <field name="distributed">
+ <boolean>true</boolean>
+ </field>
+ </object>
+ </object-param>
+ </init-params>
+ </component-plugin>
+ </external-component-plugins>-->
</configuration>
\ No newline at end of file
13 years, 3 months
gatein SVN: r7538 - in components/wsrp/trunk: admin-gui and 14 other directories.
by do-not-reply@jboss.org
Author: chris.laprun(a)jboss.com
Date: 2011-09-27 13:02:31 -0400 (Tue, 27 Sep 2011)
New Revision: 7538
Modified:
components/wsrp/trunk/admin-gui/pom.xml
components/wsrp/trunk/api/pom.xml
components/wsrp/trunk/common/pom.xml
components/wsrp/trunk/consumer/pom.xml
components/wsrp/trunk/hibernate-impl/pom.xml
components/wsrp/trunk/jcr-impl/pom.xml
components/wsrp/trunk/pom.xml
components/wsrp/trunk/producer/pom.xml
components/wsrp/trunk/test/pom.xml
components/wsrp/trunk/ws-security/jboss5/pom.xml
components/wsrp/trunk/ws-security/pom.xml
components/wsrp/trunk/ws-security/wsrp-producer-jb5wss-producer-war/pom.xml
components/wsrp/trunk/ws-security/wss/pom.xml
components/wsrp/trunk/wsrp-producer-war/pom.xml
components/wsrp/trunk/wsrp1-ws/pom.xml
components/wsrp/trunk/wsrp2-ws/pom.xml
Log:
[maven-release-plugin] prepare for next development iteration
Modified: components/wsrp/trunk/admin-gui/pom.xml
===================================================================
--- components/wsrp/trunk/admin-gui/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/admin-gui/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-admin-gui</artifactId>
Modified: components/wsrp/trunk/api/pom.xml
===================================================================
--- components/wsrp/trunk/api/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/api/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-integration-api</artifactId>
Modified: components/wsrp/trunk/common/pom.xml
===================================================================
--- components/wsrp/trunk/common/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/common/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-common</artifactId>
Modified: components/wsrp/trunk/consumer/pom.xml
===================================================================
--- components/wsrp/trunk/consumer/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/consumer/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-consumer</artifactId>
Modified: components/wsrp/trunk/hibernate-impl/pom.xml
===================================================================
--- components/wsrp/trunk/hibernate-impl/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/hibernate-impl/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -28,7 +28,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<groupId>org.gatein.wsrp</groupId>
Modified: components/wsrp/trunk/jcr-impl/pom.xml
===================================================================
--- components/wsrp/trunk/jcr-impl/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/jcr-impl/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -26,7 +26,7 @@
<parent>
<artifactId>wsrp-parent</artifactId>
<groupId>org.gatein.wsrp</groupId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
Modified: components/wsrp/trunk/pom.xml
===================================================================
--- components/wsrp/trunk/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -29,7 +29,7 @@
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
<packaging>pom</packaging>
@@ -40,9 +40,9 @@
</parent>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/gatein/components/wsrp/tags/2.1.0-...</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/gatein/components/wsrp/tags/2.1.0-Beta06</developerConnection>
- <url>http://fisheye.jboss.org/browse/gatein/components/wsrp/tags/2.1.0-Beta06</url>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/gatein/components/wsrp/trunk/</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/gatein/components/wsrp/trunk/</developerConnection>
+ <url>http://fisheye.jboss.org/browse/gatein/components/wsrp/trunk/</url>
</scm>
<properties>
Modified: components/wsrp/trunk/producer/pom.xml
===================================================================
--- components/wsrp/trunk/producer/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/producer/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-producer-lib</artifactId>
Modified: components/wsrp/trunk/test/pom.xml
===================================================================
--- components/wsrp/trunk/test/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/test/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -26,7 +26,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
Modified: components/wsrp/trunk/ws-security/jboss5/pom.xml
===================================================================
--- components/wsrp/trunk/ws-security/jboss5/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/ws-security/jboss5/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-wss-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-wss-jboss5</artifactId>
Modified: components/wsrp/trunk/ws-security/pom.xml
===================================================================
--- components/wsrp/trunk/ws-security/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/ws-security/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -27,7 +27,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<artifactId>wsrp-wss-parent</artifactId>
Modified: components/wsrp/trunk/ws-security/wsrp-producer-jb5wss-producer-war/pom.xml
===================================================================
--- components/wsrp/trunk/ws-security/wsrp-producer-jb5wss-producer-war/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/ws-security/wsrp-producer-jb5wss-producer-war/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-wss-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-producer-jb5wss</artifactId>
Modified: components/wsrp/trunk/ws-security/wss/pom.xml
===================================================================
--- components/wsrp/trunk/ws-security/wss/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/ws-security/wss/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-wss-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-wss</artifactId>
Modified: components/wsrp/trunk/wsrp-producer-war/pom.xml
===================================================================
--- components/wsrp/trunk/wsrp-producer-war/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/wsrp-producer-war/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -26,7 +26,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
Modified: components/wsrp/trunk/wsrp1-ws/pom.xml
===================================================================
--- components/wsrp/trunk/wsrp1-ws/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/wsrp1-ws/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.wsrp</groupId>
<artifactId>wsrp-parent</artifactId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-wsrp1-ws</artifactId>
Modified: components/wsrp/trunk/wsrp2-ws/pom.xml
===================================================================
--- components/wsrp/trunk/wsrp2-ws/pom.xml 2011-09-27 17:02:01 UTC (rev 7537)
+++ components/wsrp/trunk/wsrp2-ws/pom.xml 2011-09-27 17:02:31 UTC (rev 7538)
@@ -26,7 +26,7 @@
<parent>
<artifactId>wsrp-parent</artifactId>
<groupId>org.gatein.wsrp</groupId>
- <version>2.1.0-Beta06</version>
+ <version>2.1.0-CR01-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>wsrp-wsrp2-ws</artifactId>
13 years, 3 months
--- epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java 2011-09-28 09:58:15 UTC (rev 7545)
+++ epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java 2011-09-28 10:11:21 UTC (rev 7546)
@@ -30,6 +30,7 @@
import org.exoplatform.portal.config.DataStorage;
import org.exoplatform.portal.pc.ExoKernelIntegration;
import org.exoplatform.portal.pom.config.POMSessionManager;
+import org.exoplatform.services.cache.CacheService;
import org.exoplatform.services.jcr.ext.hierarchy.NodeHierarchyCreator;
import org.exoplatform.services.listener.ListenerService;
import org.gatein.common.logging.Logger;
@@ -40,6 +41,7 @@
import org.gatein.integration.wsrp.structure.PortalStructureAccess;
import org.gatein.pc.api.PortletInvoker;
import org.gatein.pc.federation.FederatingPortletInvoker;
+import org.gatein.pc.federation.PortletInvokerResolver;
import org.gatein.pc.portlet.PortletInvokerInterceptor;
import org.gatein.pc.portlet.aspects.EventPayloadInterceptor;
import org.gatein.pc.portlet.container.ContainerPortletInvoker;
@@ -61,9 +63,9 @@
import org.gatein.wsrp.WSRPConstants;
import org.gatein.wsrp.consumer.migration.JCRMigrationService;
import org.gatein.wsrp.consumer.migration.MigrationService;
-import org.gatein.wsrp.consumer.registry.ActivatingNullInvokerHandler;
import org.gatein.wsrp.consumer.registry.ConsumerRegistry;
import org.gatein.wsrp.consumer.registry.JCRConsumerRegistry;
+import org.gatein.wsrp.consumer.registry.RegisteringPortletInvokerResolver;
import org.gatein.wsrp.payload.WSRPEventPayloadInterceptor;
import org.gatein.wsrp.producer.ProducerHolder;
import org.gatein.wsrp.producer.WSRPProducer;
@@ -184,6 +186,7 @@
}
catch (Exception e)
{
+ log.debug("Couldn't load WSRP producer configuration from " + producerConfigLocation, e);
throw new RuntimeException("Couldn't load WSRP producer configuration from " + producerConfigLocation, e);
}
container.registerComponentInstance(ProducerConfigurationService.class, producerConfigurationService);
@@ -198,6 +201,7 @@
}
catch (Exception e)
{
+ log.debug("Couldn't instantiate RegistrationPersistenceManager", e);
throw new RuntimeException("Couldn't instantiate RegistrationPersistenceManager", e);
}
RegistrationManager registrationManager = new RegistrationManagerImpl();
@@ -251,6 +255,7 @@
}
catch (Exception e)
{
+ log.debug("Couldn't instantiate PortletStatePersistenceManager", e);
throw new RuntimeException("Couldn't instantiate PortletStatePersistenceManager", e);
}
@@ -327,13 +332,14 @@
consumerRegistry.start();
- // set up a NullInvokerHandler so that when a remote producer is queried, we can start it if needed
- ActivatingNullInvokerHandler handler = new ActivatingNullInvokerHandler();
- handler.setConsumerRegistry(consumerRegistry);
- federatingPortletInvoker.setNullInvokerHandler(handler);
+ // set up a PortletInvokerResolver so that when a remote producer is queried, we can start it if needed
+ RegisteringPortletInvokerResolver resolver = new RegisteringPortletInvokerResolver();
+ resolver.setConsumerRegistry(consumerRegistry);
+ federatingPortletInvoker.setPortletInvokerResolver(resolver);
}
catch (Exception e)
{
+ log.debug(e);
throw new RuntimeException("Couldn't start WSRP consumers registry from configuration " + consumersConfigLocation, e);
}
container.registerComponentInstance(ConsumerRegistry.class, consumerRegistry);
@@ -370,6 +376,7 @@
}
catch (Exception e)
{
+ log.debug(e);
throw new RuntimeException("Couldn't stop WSRP consumers registry.", e);
}
Modified: epp/portal/branches/EPP_5_2_Branch/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml
===================================================================
--- portal/trunk/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java 2011-09-27 17:02:31 UTC (rev 7538)
+++ portal/trunk/wsrp-integration/extension-component/src/main/java/org/gatein/integration/wsrp/WSRPServiceIntegration.java 2011-09-27 17:34:56 UTC (rev 7539)
@@ -30,6 +30,7 @@
import org.exoplatform.portal.config.DataStorage;
import org.exoplatform.portal.pc.ExoKernelIntegration;
import org.exoplatform.portal.pom.config.POMSessionManager;
+import org.exoplatform.services.cache.CacheService;
import org.exoplatform.services.jcr.ext.hierarchy.NodeHierarchyCreator;
import org.exoplatform.services.listener.ListenerService;
import org.gatein.common.logging.Logger;
@@ -40,6 +41,7 @@
import org.gatein.integration.wsrp.structure.PortalStructureAccess;
import org.gatein.pc.api.PortletInvoker;
import org.gatein.pc.federation.FederatingPortletInvoker;
+import org.gatein.pc.federation.PortletInvokerResolver;
import org.gatein.pc.portlet.PortletInvokerInterceptor;
import org.gatein.pc.portlet.aspects.EventPayloadInterceptor;
import org.gatein.pc.portlet.container.ContainerPortletInvoker;
@@ -61,9 +63,9 @@
import org.gatein.wsrp.WSRPConstants;
import org.gatein.wsrp.consumer.migration.JCRMigrationService;
import org.gatein.wsrp.consumer.migration.MigrationService;
-import org.gatein.wsrp.consumer.registry.ActivatingNullInvokerHandler;
import org.gatein.wsrp.consumer.registry.ConsumerRegistry;
import org.gatein.wsrp.consumer.registry.JCRConsumerRegistry;
+import org.gatein.wsrp.consumer.registry.RegisteringPortletInvokerResolver;
import org.gatein.wsrp.payload.WSRPEventPayloadInterceptor;
import org.gatein.wsrp.producer.ProducerHolder;
import org.gatein.wsrp.producer.WSRPProducer;
@@ -184,6 +186,7 @@
}
catch (Exception e)
{
+ log.debug("Couldn't load WSRP producer configuration from " + producerConfigLocation, e);
throw new RuntimeException("Couldn't load WSRP producer configuration from " + producerConfigLocation, e);
}
container.registerComponentInstance(ProducerConfigurationService.class, producerConfigurationService);
@@ -198,6 +201,7 @@
}
catch (Exception e)
{
+ log.debug("Couldn't instantiate RegistrationPersistenceManager", e);
throw new RuntimeException("Couldn't instantiate RegistrationPersistenceManager", e);
}
RegistrationManager registrationManager = new RegistrationManagerImpl();
@@ -251,6 +255,7 @@
}
catch (Exception e)
{
+ log.debug("Couldn't instantiate PortletStatePersistenceManager", e);
throw new RuntimeException("Couldn't instantiate PortletStatePersistenceManager", e);
}
@@ -309,6 +314,14 @@
consumerRegistry.setSessionEventBroadcaster(sessionEventBroadcaster);
consumerRegistry.setConfigurationIS(consumersConfigurationIS);
+ // if we run in a cluster, use a distributed cache for consumers
+ /*if (ExoContainer.getProfiles().contains("cluster"))
+ {
+ CacheService cacheService = (CacheService)container.getComponentInstanceOfType(CacheService.class);
+ DistributedConsumerCache consumerCache = new DistributedConsumerCache(cacheService);
+ consumerRegistry.setConsumerCache(consumerCache);
+ }*/
+
// create ConsumerStructureProvider and register it to listen to page events
POMSessionManager sessionManager = (POMSessionManager)container.getComponentInstanceOfType(POMSessionManager.class);
PortalStructureAccess structureAccess = new MOPPortalStructureAccess(sessionManager);
@@ -327,13 +340,14 @@
consumerRegistry.start();
- // set up a NullInvokerHandler so that when a remote producer is queried, we can start it if needed
- ActivatingNullInvokerHandler handler = new ActivatingNullInvokerHandler();
- handler.setConsumerRegistry(consumerRegistry);
- federatingPortletInvoker.setNullInvokerHandler(handler);
+ // set up a PortletInvokerResolver so that when a remote producer is queried, we can start it if needed
+ RegisteringPortletInvokerResolver resolver = new RegisteringPortletInvokerResolver();
+ resolver.setConsumerRegistry(consumerRegistry);
+ federatingPortletInvoker.setPortletInvokerResolver(resolver);
}
catch (Exception e)
{
+ log.debug(e);
throw new RuntimeException("Couldn't start WSRP consumers registry from configuration " + consumersConfigLocation, e);
}
container.registerComponentInstance(ConsumerRegistry.class, consumerRegistry);
@@ -370,6 +384,7 @@
}
catch (Exception e)
{
+ log.debug(e);
throw new RuntimeException("Couldn't stop WSRP consumers registry.", e);
}
Modified: portal/trunk/wsrp-integration/extension-component/src/main/resources/conf/wsrp-consumers-config.xml
===================================================================